<?php

namespace Drupal\commerce_affirm\Event;

use Drupal\commerce\EventBase;

/**
 * Defines an event for altering the Affirm locale.
 *
 * @see \Drupal\commerce_affirm\Event\AffirmEvents
 */
class AffirmLocaleEvent extends EventBase {

  /**
   * The locale to pass to Affirm.
   *
   * @var string
   */
  protected $locale;

  /**
   * Constructs a new AffirmLocaleEvent object.
   *
   * @param string $locale
   *   The Affirm default locale configuration.
   */
  public function __construct(string $locale) {
    $this->locale = $locale;
  }

  /**
   * Gets the Affirm locale configuration.
   *
   * @return string
   *   The Affirm locale configuration.
   */
  public function getLocale() {
    return $this->locale;
  }

  /**
   * Sets the Affirm locale configuration.
   *
   * @param string $locale
   *   The locale.
   *
   * @return $this
   */
  public function setLocale(string $locale) {
    $this->locale = $locale;
    return $this;
  }

}
