<?php

namespace Drupal\commerce_affirm\Plugin\Commerce\CheckoutPane;

use Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowInterface;
use Drupal\commerce_checkout\Plugin\Commerce\CheckoutPane\CheckoutPaneBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the Affirm checkout completion analytics pane.
 *
 * @CommerceCheckoutPane(
 *   id = "affirm_checkout_completion_analytics",
 *   label = @Translation("Affirm checkout completion analytics"),
 *   default_step = "complete",
 * )
 */
class CheckoutCompletionAnalytics extends CheckoutPaneBase {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The minor units converter.
   *
   * @var \Drupal\commerce_price\MinorUnitsConverterInterface
   */
  protected $minorUnitsConverter;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition, ?CheckoutFlowInterface $checkout_flow = NULL): self {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition, $checkout_flow);
    $instance->configFactory = $container->get('config.factory');
    $instance->minorUnitsConverter = $container->get('commerce_price.minor_units_converter');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function buildPaneForm(array $pane_form, FormStateInterface $form_state, array &$complete_form): array {
    $analytics = $this->configFactory->get('commerce_affirm.settings')->get('analytics');
    if ($analytics && empty($this->order->getData('commerce_affirm_analytics_sent', 0))) {
      $order_total = $this->order->getTotalPrice();
      $data = [
        'checkoutComplete' => [
          'order' => [
            'orderId' => $this->order->id(),
            'currency' => $order_total->getCurrencyCode(),
            'total' => $this->minorUnitsConverter->toMinorUnits($order_total),
            'storeName' => $this->order->getStore()->label(),
            'paymentMethod' => $this->order->get('payment_gateway')->entity->getPlugin()->getLabel(),
          ],
        ],
      ];
      foreach ($this->order->getItems() as $item) {
        $data['checkoutComplete']['products'][] = [
          'price' => $this->minorUnitsConverter->toMinorUnits($item->getTotalPrice()),
          'productId' => $item->getPurchasedEntityId(),
          'quantity' => $item->getQuantity(),
        ];
      }

      $pane_form['#attached']['drupalSettings']['commerceAffirmAnalytics'] = $data;
      $pane_form['#attached']['library'][] = 'commerce_affirm/affirm-checkout-analytics';
      $this->order->setData('commerce_affirm_analytics_sent', TRUE);
      $this->order->save();
    }

    return $pane_form;
  }

}
