<?php

namespace Drupal\commerce_affirm\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'commerce_affirm_messaging' formatter.
 *
 * @FieldFormatter(
 *   id = "commerce_affirm_messaging",
 *   label = @Translation("Affirm"),
 *   field_types = {
 *     "commerce_price"
 *   }
 * )
 */
class AffirmFormatter extends FormatterBase implements ContainerFactoryPluginInterface {

  /**
   * The minor units converter.
   *
   * @var \Drupal\commerce_price\MinorUnitsConverterInterface
   */
  protected $minorUnitsConverter;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->minorUnitsConverter = $container->get('commerce_price.minor_units_converter');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings(): array {
    return [
      'page_type' => 'product',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state): array {
    $form = parent::settingsForm($form, $form_state);

    $form['page_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Page type'),
      '#default_value' => $this->getSetting('page_type'),
      '#options' => commerce_affirm_get_page_types(),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary(): array {
    $summary = [];
    $summary[] = $this->t('Page type: @page_type', [
      '@page_type' => $this->getSetting('page_type'),
    ]);

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];

    foreach ($items as $delta => $item) {
      $price = NULL;
      $entity = $item->getEntity();
      /** @var \Drupal\commerce_price\Entity\CurrencyInterface $currency */
      switch ($entity->getEntityTypeId()) {
        case 'commerce_product_variation':
          /** @var \Drupal\commerce_product\Entity\ProductVariationInterface $entity */
          $price = $entity->getPrice();
          break;

        case 'commerce_order':
          /** @var \Drupal\commerce_order\Entity\OrderInterface $entity */
          $price = $entity->getTotalPrice();
          break;
      }
      if ($price) {
        $number = $this->minorUnitsConverter->toMinorUnits($price);
        $elements[$delta] = [
          '#theme' => 'commerce_affirm_monthly_payment_message',
          '#page_type' => $this->getSetting('page_type'),
          '#number' => $number,
          '#variation' => $entity,
        ];
      }
    }

    return $elements;
  }

}
