<?php

namespace Drupal\commerce_affirm\PluginForm;

use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerTrait;

/**
 * Provides an offsite payment form for Affirm.
 */
class RedirectForm extends PaymentOffsiteForm {

  use MessengerTrait;

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);
    /** @var \Drupal\commerce_affirm\Plugin\Commerce\PaymentGateway\Redirect $plugin */
    $plugin = $this->plugin;

    if (empty($plugin->getPublicKey())) {
      $this->messenger->addError($this->t('Affirm is not configured for use. You must check your settings.'));
      return [];
    }

    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->getEntity();
    $order = $payment->getOrder();

    $js_settings = $plugin->getAffirmCheckoutSettings($order);
    $form['#attached']['library'][] = 'commerce_affirm/affirm-checkout';
    $form['#attached']['drupalSettings']['commerceAffirm'] = $js_settings;

    return $form;
  }

}
